@@ -112,12 +112,14 @@ extern void buf_free PROTO((struct buffer *));
 extern struct buffer *buf_nonio_initialize PROTO((void (*) (struct buffer *)));
 extern struct buffer *stdio_buffer_initialize
   PROTO((FILE *, int, int, void (*) (struct buffer *)));
+extern FILE *stdio_buffer_get_file PROTO((struct buffer *));
 extern struct buffer *compress_buffer_initialize
   PROTO((struct buffer *, int, int, void (*) (struct buffer *)));
 extern struct buffer *packetizing_buffer_initialize
   PROTO((struct buffer *, int (*) (void *, const char *, char *, int),
 	 int (*) (void *, const char *, char *, int, int *), void *,
 	 void (*) (struct buffer *)));
+extern int buf_empty PROTO((struct buffer *));
 extern int buf_empty_p PROTO((struct buffer *));
 extern void buf_output PROTO((struct buffer *, const char *, int));
 extern void buf_output0 PROTO((struct buffer *, const char *));
