@@ -1,6 +1,11 @@
 /*
- * Copyright (c) 1992, Brian Berliner and Jeff Polk
- * Copyright (c) 1989-1992, Brian Berliner
+ * Copyright (C) 1986-2005 The Free Software Foundation, Inc.
+ *
+ * Portions Copyright (C) 1998-2005 Derek Price, Ximbiot <http://ximbiot.com>,
+ *                                  and others.
+ *
+ * Portions Copyright (C) 1992, Brian Berliner and Jeff Polk
+ * Portions Copyright (C) 1989-1992, Brian Berliner
  * 
  * You may distribute under the terms of the GNU General Public License as
  * specified in the README file that comes with the CVS source distribution.
@@ -22,38 +27,35 @@
    don't print warnings; all errors are fatal then.  */
 
 int
-Create_Admin (dir, update_dir, repository, tag, date, nonbranch, warn)
-    char *dir;
-    char *update_dir;
-    char *repository;
-    char *tag;
-    char *date;
+Create_Admin (dir, update_dir, repository, tag, date, nonbranch, warn,
+	      dotemplate)
+    const char *dir;
+    const char *update_dir;
+    const char *repository;
+    const char *tag;
+    const char *date;
     int nonbranch;
     int warn;
+    int dotemplate;
 {
     FILE *fout;
     char *cp;
     char *reposcopy;
     char *tmp;
 
-#ifdef SERVER_SUPPORT
     if (trace)
     {
-	fprintf (stderr, "%c-> Create_Admin (%s, %s, %s, %s, %s, %d, %d)\n",
-		 (server_active) ? 'S' : ' ',
+	fprintf (stderr, "%s-> Create_Admin (%s, %s, %s, %s, %s, %d, %d, %d)\n",
+		 CLIENT_SERVER_STR,
 		 dir, update_dir, repository, tag ? tag : "",
-		 date ? date : "", nonbranch, warn);
+		 date ? date : "", nonbranch, warn, dotemplate);
     }
-#endif
 
     if (noexec)
 	return 0;
 
     tmp = xmalloc (strlen (dir) + 100);
-    if (dir != NULL)
-	(void) sprintf (tmp, "%s/%s", dir, CVSADM);
-    else
-	(void) strcpy (tmp, CVSADM);
+    (void) sprintf (tmp, "%s/%s", dir, CVSADM);
     if (isfile (tmp))
 	error (1, 0, "there is a version in %s already", update_dir);
 
@@ -84,7 +86,7 @@ Create_Admin (dir, update_dir, repository, tag, date, nonbranch, warn)
 
     /* record the current cvs root for later use */
 
-    Create_Root (dir, CVSroot_original);
+    Create_Root (dir, current_parsed_root->original);
     if (dir != NULL)
 	(void) sprintf (tmp, "%s/%s", dir, CVSADM_REP);
     else
@@ -106,7 +108,7 @@ Create_Admin (dir, update_dir, repository, tag, date, nonbranch, warn)
        spend the time making sure all of the code can handle it if we
        don't do it. */
 
-    if (strcmp (reposcopy, CVSroot_directory) == 0)
+    if (strcmp (reposcopy, current_parsed_root->directory) == 0)
     {
 	reposcopy = xrealloc (reposcopy, strlen (reposcopy) + 3);
 	strcat (reposcopy, "/.");
@@ -114,21 +116,18 @@ Create_Admin (dir, update_dir, repository, tag, date, nonbranch, warn)
 
     cp = reposcopy;
 
-#ifdef RELATIVE_REPOS
     /*
      * If the Repository file is to hold a relative path, try to strip off
      * the leading CVSroot argument.
      */
-    if (CVSroot_directory != NULL)
     {
-	char *path = xmalloc (strlen (CVSroot_directory) + 10);
+    char *path = xmalloc (strlen (current_parsed_root->directory) + 2);
 
-	(void) sprintf (path, "%s/", CVSroot_directory);
-	if (strncmp (cp, path, strlen (path)) == 0)
-	    cp += strlen (path);
-	free (path);
+    (void) sprintf (path, "%s/", current_parsed_root->directory);
+    if (strncmp (cp, path, strlen (path)) == 0)
+	cp += strlen (path);
+    free (path);
     }
-#endif
 
     if (fprintf (fout, "%s\n", cp) < 0)
     {
@@ -170,7 +169,7 @@ Create_Admin (dir, update_dir, repository, tag, date, nonbranch, warn)
     WriteTag (dir, tag, date, nonbranch, update_dir, repository);
 
 #ifdef SERVER_SUPPORT
-    if (server_active)
+    if (server_active && dotemplate)
     {
 	server_template (update_dir, repository);
     }
